/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 1002 $
 * $Date: 2020-04-10 23:31:24 +0200 (Fri, 10 Apr 2020) $
 */
package at.lcm.bu21.general.dtypes.editor2;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;

import javax.swing.DefaultCellEditor;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.JTextField;
import javax.swing.ScrollPaneConstants;
import javax.swing.table.JTableHeader;
import javax.swing.table.TableCellRenderer;
import javax.swing.table.TableColumn;
import javax.swing.text.JTextComponent;

import at.lcm.bu21.general.dtypes.editor2.TDataModel.TStringModel;

/**
 * This panel allows to analyze and manipulate TStrings. It based on
 * TStringModel and TStringTableModel for JTables.
 * 
 * @author Johannes Kaisinger
 */
public class TStringPanel extends JPanel {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/**
	 * Local reference of the TStringModel. It allows to manipulate the TString.
	 */
	private TStringModel tStringModel;

	/** Contains a table model for the JTable. */
	private TStringTableModel tableModel;

	/** Editor as table. */
	private JTable table;

	/**
	 * Creates an object
	 * 
	 * @param tStringModel
	 *            The TStringModel
	 */
	public TStringPanel(TStringModel tStringModel) {

		this.tStringModel = tStringModel;

		this.setLayout(new BorderLayout());

		this.tableModel = new TStringTableModel(this.tStringModel);
		this.table = new JTable(this.tableModel) {

			/** Serialization version number */
			private static final long serialVersionUID = 1L;

			@Override
			public Component prepareRenderer(TableCellRenderer renderer, int row, int column) {
				Component component = super.prepareRenderer(renderer, row, column);
				int rendererWidth = component.getPreferredSize().width;
				TableColumn tableColumn = this.getColumnModel().getColumn(column);

				int width = rendererWidth + this.getIntercellSpacing().width;

				if (width < 50) {
					width = 50;
				}

				tableColumn.setPreferredWidth(width);
				return component;
			}
		};
		this.setColWdith(100);

		// this.tableModel.addTableModelListener(new TableModelListener() {
		//
		// @Override
		// public void tableChanged(TableModelEvent e) {
		//
		// TableColumn tableColumn =
		// TStringPanel.this.table.getColumnModel().getColumn(0);
		// int preferredWidth = tableColumn.getMinWidth();
		//
		// TableCellRenderer cellRenderer =
		// TStringPanel.this.table.getCellRenderer(0, 0);
		// Component c = TStringPanel.this.table.prepareRenderer(cellRenderer,
		// 0, 0);
		// int width = c.getPreferredSize().width +
		// TStringPanel.this.table.getIntercellSpacing().width;
		//
		// preferredWidth = Math.max(preferredWidth, width);
		//
		// tableColumn.setPreferredWidth(preferredWidth);
		// }
		// });

		this.table.setCellSelectionEnabled(true);

		this.table.setDefaultEditor(Object.class, new DefaultCellEditor(new JTextField()) {

			/** Serialization version number */
			private static final long serialVersionUID = 1L;

			@Override
			public Component getTableCellEditorComponent(final JTable table, final Object value,
					final boolean isSelected, final int row, final int column) {
				Component c;
				c = super.getTableCellEditorComponent(table, value, isSelected, row, column);
				((JTextField) c).selectAll();
				return c;
			}
		});

		this.createMouseListener();

		// configurate table Header
		JTableHeader tableHeader = this.table.getTableHeader();
		tableHeader.setReorderingAllowed(false);

		JScrollPane scroll = new JScrollPane(this.table);

		RowHeaderTable rowHeaderTable = new RowHeaderTable(this.table);
		scroll.setRowHeaderView(rowHeaderTable);
		scroll.setCorner(ScrollPaneConstants.UPPER_LEFT_CORNER, rowHeaderTable.getTableHeader());

		this.add(scroll, BorderLayout.CENTER);
		this.setVisible(true);
	}

	/**
	 * set the column width.
	 * 
	 * @param width
	 *            Width of the column.
	 */
	private void setColWdith(int width) {
		this.table.setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
		for (int c = 0; c < this.table.getColumnCount(); c++) {
			this.table.getColumnModel().getColumn(c).setMinWidth(width);
			this.table.getColumnModel().getColumn(c).setPreferredWidth(width);
		}
	}

	/**
	 * Adds a mouse listener to the table.
	 */
	private void createMouseListener() {
		this.table.addMouseListener(new MouseAdapter() {
			@Override
			public void mousePressed(MouseEvent e) {
				if (e.getClickCount() == 2) {
					Component editor = TStringPanel.this.table.getEditorComponent();
					editor.requestFocusInWindow();
					((JTextComponent) editor).selectAll();
				}
			}
		});
	}

}
