/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.math.autodiff;

/**
 * Product for multiple multiplicand
 * 
 * @author Gnther Weidenholzer
 * @author Werner Koppelsttter
 */
public class Product extends Func {

	/**
	 * Constructor for multiple multiplicands
	 * 
	 * @param args
	 *            Variable count of multiplicands
	 */
	public Product(Func... args) {
		super(args);
	}

	@Override
	public double value() throws Exception {
		double val = 1.0;

		for (int k = 0; k < this.getNumArgs(); k++) {
			val *= this.getArg(k).value();
		}

		return val;
	}

	/**
	 * Derivation of product
	 * 
	 * @param var
	 *            Variable for derivation
	 * @return Derivative function
	 * @throws Exception
	 *             Derivative exception
	 */
	@Override
	public Func derivative(Variable var) throws Exception {
		Product[] prod;
		Func[] func;

		prod = new Product[this.getNumArgs()];
		for (int k = 0; k < prod.length; k++) {
			func = new Func[prod.length];
			for (int m = 0; m < func.length; m++) {
				func[m] = this.getArg(m);
				if (k == m) {
					func[m] = func[m].derivative(var);
				}
			}
			prod[k] = new Product(func);
		}

		return new Sum(prod);
	}

	@Override
	public String toString() {
		String str;

		str = "(";
		try {
			str += this.getArg(0).toString();
		} catch (Exception e) {
			str += "'?'";
		}
		for (int k = 1; k < this.getNumArgs(); k++) {
			try {
				str += "*" + this.getArg(k).toString();
			} catch (Exception e) {
				str += "'?'";
			}
		}
		str += ")";

		return str;
	}
}
