/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 997 $
 * $Date: 2020-03-19 13:49:34 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.general.plot;

import java.awt.BorderLayout;
import java.awt.Component;
import java.awt.Point;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.GroupLayout;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.SwingConstants;
import javax.swing.WindowConstants;
import javax.swing.border.EmptyBorder;

/**
 * Dialog to select save settings
 * 
 * @author Werner Koppelsttter
 */
public class SaveSettingsDialog extends JDialog {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Text-field for width */
	private JTextField fldWidth;

	/** Test-field for height */
	private JTextField fldHeight;

	/** Is size valid */
	private boolean valid = false;

	/**
	 * Create dialog
	 */
	private SaveSettingsDialog() {
		super();
		this.init();
	}

	/**
	 * Create dialog on screen position
	 * 
	 * @param x
	 *            X position on screen
	 * @param y
	 *            Y position on screen
	 */
	public SaveSettingsDialog(int x, int y) {
		this();
		this.setLocation(x, y);
	}

	/**
	 * Create dialog relative to component
	 * 
	 * @param comp
	 *            Parant component
	 */
	public SaveSettingsDialog(Component comp) {
		this();
		Point loc = comp.getLocationOnScreen();
		this.setLocation((loc.x + (comp.getWidth() / 2))
				- (this.getWidth() / 2), (loc.y + (comp.getHeight() / 2))
				- (this.getHeight() / 2));
	}

	/**
	 * Initialize dialog
	 */
	private void init() {
		JPanel settings, button;
		JLabel lbSize, lbWidth, lbHeight, lbX, lbX1;

		this.setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
		this.setModal(true);
		this.setTitle("Size of plot?");
		this.getContentPane().setLayout(new BorderLayout());

		// size panel
		settings = new JPanel();
		settings.setBorder(new EmptyBorder(10, 10, 10, 10));
		GroupLayout gl_settings = new GroupLayout(settings);
		settings.setLayout(gl_settings);

		lbSize = new JLabel("Size:");
		settings.add(lbSize);

		lbWidth = new JLabel("width", SwingConstants.CENTER);
		settings.add(lbWidth);

		lbX = new JLabel("x", SwingConstants.CENTER);
		settings.add(lbX);

		lbHeight = new JLabel("height", SwingConstants.CENTER);
		settings.add(lbHeight);

		this.fldWidth = new JTextField(6);
		this.fldWidth.setText("500");
		this.fldWidth.setHorizontalAlignment(SwingConstants.CENTER);
		settings.add(this.fldWidth);

		lbX1 = new JLabel("x", SwingConstants.CENTER);
		settings.add(lbX1);

		this.fldHeight = new JTextField(6);
		this.fldHeight.setText("400");
		this.fldHeight.setHorizontalAlignment(SwingConstants.CENTER);
		settings.add(this.fldHeight);

		// this.ckbInital = new JCheckBox("Inital Plot", true);
		// settings.add(this.ckbInital);

		gl_settings.setAutoCreateGaps(true);
		gl_settings.setAutoCreateContainerGaps(true);
		gl_settings.setHorizontalGroup(gl_settings
				.createSequentialGroup()
				.addComponent(lbSize)
				.addGroup(
						gl_settings
								.createParallelGroup(
										GroupLayout.Alignment.CENTER)
								.addComponent(lbWidth)
								.addComponent(this.fldWidth))
				.addGroup(
						gl_settings
								.createParallelGroup(
										GroupLayout.Alignment.CENTER)
								.addComponent(lbX).addComponent(lbX1))
				.addGroup(
						gl_settings
								.createParallelGroup(
										GroupLayout.Alignment.CENTER)
								.addComponent(lbHeight)
								.addComponent(this.fldHeight)));
		gl_settings.setVerticalGroup(gl_settings
				.createSequentialGroup()
				.addGroup(
						gl_settings
								.createParallelGroup(
										GroupLayout.Alignment.BASELINE)
								.addComponent(lbSize).addComponent(lbWidth)
								.addComponent(lbX).addComponent(lbHeight))
				.addGroup(
						gl_settings
								.createParallelGroup(
										GroupLayout.Alignment.BASELINE)
								.addComponent(this.fldWidth).addComponent(lbX1)
								.addComponent(this.fldHeight)).addGap(10));

		this.getContentPane().add(settings, BorderLayout.CENTER);

		// buttons
		button = new JPanel();

		JButton ok = new JButton("OK");
		button.add(ok);
		ok.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent event) {
				SaveSettingsDialog.this.dispose();
				SaveSettingsDialog.this.valid = true;
			}
		});

		JButton cancel = new JButton("Cancel");
		button.add(cancel);
		cancel.addActionListener(new ActionListener() {

			@Override
			public void actionPerformed(ActionEvent event) {
				SaveSettingsDialog.this.dispose();
			}
		});

		this.getContentPane().add(button, BorderLayout.SOUTH);

		this.pack();
	}

	/**
	 * Check if plot-size is valid
	 * 
	 * @return Is valid
	 */
	public boolean isValidPlotSize() {
		return this.valid;
	}

	/**
	 * Set default width and height of plot
	 * 
	 * @param width
	 *            Width
	 * @param height
	 *            Height
	 */
	public void setPlotSize(int width, int height) {
		this.fldWidth.setText(Integer.toString(width));
		this.fldHeight.setText(Integer.toString(height));
	}

	/**
	 * Get width of plot
	 * 
	 * @return Width
	 */
	public int getPlotWidth() {
		return Integer.parseInt(this.fldWidth.getText());
	}

	/**
	 * Get height of plot
	 * 
	 * @return Height
	 */
	public int getPlotHeight() {
		return Integer.parseInt(this.fldHeight.getText());
	}
}
