import pickle
import base64


def serialize_instance(instance, decoding='ascii'):
    """
    Serialize any python instance to a string
    The instance gets pickled and base64 encoded

    Parameters
    ----------

    instance : object
            Any object instance
    decoding : string
            Decoding style Default('ascii')

    Returns
    -------
    basestring
    """

    ''' pickle instance '''
    pickled = pickle.dumps(instance)
    ''' encode to base64 '''
    encoded = base64.b64encode(pickled)
    ''' decode to string'''
    return encoded.decode(decoding)


def deserialize_instance(serialized_instance):
    """
    Deserialize a base64 encoded
    string representation of a pickled instance
    The serialized instance gets base64 decoded and unpickled

    Parameters
    ----------
    serialized_instance : string

    Returns
    -------
    object
    """
    ''' decode string to byte stream '''
    pickled = base64.b64decode(serialized_instance)
    ''' unpickle byte stream to instance '''
    return pickle.loads(pickled)


