/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9715 $
 * $Date: 2020-03-19 10:01:15 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.symspace.gui.views;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseMotionAdapter;

import javax.swing.JPanel;
import javax.swing.OverlayLayout;

/**
 * A panel to disable components
 *
 * @author Werner Koppelsttter
 */
public class DisablePanel extends JPanel {

	/** Translucent glass panel in front */
	private GlassPanel glass;

	/** Translucent pane */
	public class GlassPanel extends JPanel {

		/** Serialization version number */
		private static final long serialVersionUID = 1L;

		/** Create glass-pane */
		public GlassPanel() {
			this.setOpaque(false);
			this.setVisible(false);

			// background translucent
			Color base = this.getBackground();
			Color background = new Color(base.getRed(), base.getGreen(), base.getBlue(), 128);
			this.setBackground(background);

			// disable mouse events
			this.addMouseListener(new MouseAdapter() {
			});
			this.addMouseMotionListener(new MouseMotionAdapter() {
			});
		}

		@Override
		protected void paintComponent(Graphics g) {
			g.setColor(this.getBackground());
			g.fillRect(0, 0, this.getSize().width, this.getSize().height);
		}
	}

	/**
	 * 
	 * @param comp
	 *            Compoenten to display
	 */
	public DisablePanel(Component comp) {
		this.setLayout(new OverlayLayout(this));
		this.glass = new GlassPanel();
		this.add(this.glass);
		if (comp != null) {
			this.add(comp);
		}
	}

	@Override
	public boolean isEnabled() {
		return !this.glass.isVisible();
	}

	@Override
	public void setEnabled(boolean aFlag) {
		this.glass.setVisible(!aFlag);
	}

}
