/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure;

import java.util.EventObject;

/**
 * Defines an event that encapsulates changes of datasets
 *
 * @author Werner Koppelsttter
 */
public class DatasetEvent extends EventObject {

	/**
	 * Type of dataset-event
	 * 
	 * @author Werner Koppelsttter
	 */
	public enum DatasetType {
	/** Identifies the changes of index */
	DATASET_INDEX_CHANGED,
	/** Identifies the addition of one or more datasets */
	DATASET_ADDED,
	/** Identifies the removal of one or more datasets */
	DATASET_REMOVED
	}

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Type of event */
	private DatasetType type;

	/** Old index of dataset */
	private int from;

	/** New index of dataset */
	private int to;

	/**
	 * Create new event of index change
	 * 
	 * @param source
	 *            Source object <code>Project</code>
	 * @param type
	 *            Type of changes
	 * @param from
	 *            Old index
	 * @param to
	 *            New index
	 */
	public DatasetEvent(Object source, DatasetType type, int from, int to) {
		super(source);
		this.type = type;
		this.from = from;
		this.to = to;
	}

	/**
	 * Get type of event
	 * 
	 * @return Event type
	 */
	public DatasetType getType() {
		return this.type;
	}

	/**
	 * Get old index of dataset
	 * 
	 * @return Old index
	 */
	public int getFromIndex() {
		return this.from;
	}

	/**
	 * Get new index of dataset
	 * 
	 * @return New index
	 */
	public int getToIndex() {
		return this.to;
	}
}
