/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_12.
 * 
 * - Replace empty TNumeric <br>
 * - Add lock flag to Parameter <br>
 * - Add database identifier
 * 
 * @author Werner Koppelsttter
 */
class Converter_12 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {
		// Convert Parameter
		Converter_12.replaceEmptyNumeric(node);
		Converter_12.addEntries(node);

		return node;
	}

	/**
	 * Replace empty Numeric node by Null node
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void replaceEmptyNumeric(XMLNode node) {

		if (node.getName().compareTo("Numeric") == 0) {
			if (node.getText().compareTo("[]") == 0) {
				node.setName("Null");
				node.setText(null);
			}
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_12.replaceEmptyNumeric(n);
		}
	}

	/**
	 * Add new lock flag node to Parameter
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void addEntries(XMLNode node) {
		XMLNode item;

		if (node.getName().compareTo("Parameter") == 0) {
			// add enable
			item = new XMLNode("Lock");
			item.setText("false");
			node.addNode(item);
		}
		if (node.getName().compareTo("ParamField") == 0) {
			// add database identifier
			item = new XMLNode("DbId");
			item.setText("-1");
			node.addNode(item);
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_12.addEntries(n);
		}
	}
}
