/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_17.
 * 
 * - Change name of BH-Diagram of Material
 * 
 * @author Werner Koppelsttter
 */
public class Converter_17 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {
		// Convert Parameter
		Converter_17.changeMaterial(node);

		return node;
	}

	/**
	 * Change material diagram
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void changeMaterial(XMLNode node) {
		XMLNode item;

		if ((node.getName().compareTo("ParamContainer") == 0)
				&& (node.getAttribute("object").compareTo("ParamMaterial") == 0)) {
			item = node.getNode(1); // param
			for (XMLNode n : item.getNodes()) {
				Converter_17.changeBHCurve(n);
			}
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_17.changeMaterial(n);
		}
	}

	/**
	 * Change name of BH-curve
	 * 
	 * @param node
	 *            Node to change
	 */
	private static void changeBHCurve(XMLNode node) {
		XMLNode item;
		if ((node.getName().compareTo("ParamContainer") == 0)
				&& (node.getAttribute("name").compareTo("BH") == 0)) {

			// ParamContainer attribute
			node.setAttribute("name", "HvsB");

			// Parameter attribute and name
			item = node.getNode(0);
			item.setAttribute("name", "HvsB");
			item.getNode(0).setText("HvsB"); // name
		}
	}
}
