/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_2.
 * 
 * - Add ParamContainer functionality to ParamFnc
 * 
 * @author Werner Koppelsttter
 */
class Converter_2 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {

		Converter_2.updateParamFnc(node);
		return node;
	}

	/**
	 * Recursive update of ParamFnc
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void updateParamFnc(XMLNode node) {
		int i;
		XMLNode newNode, incomplete, item;

		if (node.getName().compareTo("ParamFnc") == 0) {

			// modify ParamFnc (insert ParamContainer)
			newNode = new XMLNode("ParamContainer");
			node.addNode(0, newNode);

			// copy attributes
			for (String[] a : node.getAttributes()) {
				newNode.setAttribute(a[0], a[1]);
			}

			newNode.addNode(node.rmNode(1)); // Parameter
			// add Param
			newNode.addNode(new XMLNode("Param"));

			// add incomplete
			// item
			item = new XMLNode("item");
			item.setText("true");
			// incomplete
			incomplete = new XMLNode("Incomplete");
			newNode.addNode(incomplete);

			for (i = 0; i < node.getNode(3).getNodeSize(); i++) {
				incomplete.addNode(item);
			}
		}

		// find event
		for (XMLNode n : node.getNodes()) {
			Converter_2.updateParamFnc(n);
		}
	}

}
