/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_20.
 * 
 * - Add Parameter ID <br>
 * - Add Dataset ID
 * 
 * @author Werner Koppelsttter
 */
public class Converter_20 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {
		long nextid;
		XMLNode item;

		// Add Parameter-id
		nextid = Converter_20.addPId(node, 0);
		if (node.getName().compareTo("Project") == 0) {
			item = new XMLNode("NextPID");
			item.setText(Long.toString(nextid));
			node.addNode(2, item);
		}

		// Add Dataset-id
		Converter_20.addDsId(node);

		return node;
	}

	/**
	 * Add parameter ID
	 * 
	 * @param node
	 *            Node to update
	 * @param nextID
	 *            Next id number
	 * @return Next id number
	 */
	private static long addPId(XMLNode node, long nextID) {
		XMLNode item;

		if (node.getName().compareTo("Parameter") == 0) {
			item = new XMLNode("PID");
			item.setText(Long.toString(nextID++, 36));
			node.addNode(0, item);
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			nextID = Converter_20.addPId(n, nextID);
		}

		return nextID;
	}

	/**
	 * Add dataset ID
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void addDsId(XMLNode node) {
		int len;
		XMLNode item;

		if (node.getName().compareTo("Project") == 0) {
			len = Integer.parseInt(node.getNode(0).getText());

			// next ds-id
			item = new XMLNode("NextDSID");
			item.setText(Integer.toString(len));
			node.addNode(3, item);

			// ds-id
			item = new XMLNode("DSID");
			node.addNode(5, item);
			node = item;
			for (int k = 0; k < len; k++) {
				item = new XMLNode("item");
				item.setText(Integer.toString(k, 36));
				node.addNode(item);
			}

		}

	}

}
