/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.converter;

import at.lcm.bu21.general.utils.XMLNode;

/**
 * Convert to V_0_26.
 * 
 * - Remove Combobox-index <br>
 * - Remove Temporary flag
 * 
 * @author Werner Koppelsttter
 */
public class Converter_26 {

	/**
	 * Convert the given node
	 * 
	 * @param node
	 *            Data to convert
	 * @return Changed data node
	 */
	static XMLNode convert(XMLNode node) {

		// Convert Event
		Converter_26.convertCombobox(node);
		Converter_26.rmTemporary(node);

		return node;
	}

	/**
	 * Convert Event
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void convertCombobox(XMLNode node) {

		if ((node.getName().compareTo("ParamComboBox") == 0)
				&& (node.getNodeSize() == 3)) {
			node.rmNode(2);
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_26.convertCombobox(n);
		}
	}

	/**
	 * Convert Event
	 * 
	 * @param node
	 *            Node to update
	 */
	private static void rmTemporary(XMLNode node) {

		if (node.getName().compareTo("ParamField") == 0) {
			if (node.getNode(0).getName().compareTo("Temporary") == 0) {
				node.rmNode(0);
			}
		}

		// next Node
		for (XMLNode n : node.getNodes()) {
			Converter_26.rmTemporary(n);
		}
	}
}
