/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9713 $
 * $Date: 2020-03-19 09:28:58 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.magopt.structure.rmi;

import java.rmi.RemoteException;

import at.lcm.bu21.magopt.structure.Access;
import at.lcm.bu21.magopt.structure.Component;
import at.lcm.bu21.magopt.structure.IComponent;
import at.lcm.bu21.magopt.structure.IParamContainer;
import at.lcm.bu21.magopt.structure.IParameter;
import at.lcm.bu21.magopt.structure.ParamCollector;
import at.lcm.bu21.magopt.structure.ParamContainer;
import at.lcm.bu21.magopt.structure.ParamFunction;
import at.lcm.bu21.magopt.structure.ParamMaterial;
import at.lcm.bu21.magopt.structure.Parameter;
import at.lcm.bu21.magopt.structure.Parameter.ParameterPath;
import at.lcm.bu21.magopt.structure.client.CParamContainer;

/**
 * RMI adapter for container
 * 
 * @author Werner Koppelsttter
 */
public class RParamContainer extends RParameter implements IParamContainer {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/** Container class */
	private ParamContainer param;

	/**
	 * Create rmi adapter for container
	 * 
	 * @param param
	 *            Container
	 * @throws RemoteException
	 */
	public RParamContainer(ParamContainer param) throws RemoteException {
		super(param);
		this.param = param;
	}

	@Override
	public boolean isEnable() {
		return this.param.isEnable();
	}

	@Override
	public boolean getEnable() {
		return this.param.getEnable();
	}

	@Override
	public void setEnable(boolean enable) {
		this.param.setEnable(enable);
	}

	@Override
	public Access getAccess() {
		return this.param.getAccess();
	}

	@Override
	public void setAccess(Access access) {
		this.param.setAccess(access);
	}

	@Override
	public boolean getIncomplete() {
		return this.param.getIncomplete();
	}

	@Override
	public boolean[] getAllIncomplete() {
		return this.param.getAllIncomplete();
	}

	@Override
	public IParameter[] getParam() throws RemoteException {
		Parameter[] params;
		IParameter[] rmiParams;

		params = this.param.getParam();
		rmiParams = new IParameter[params.length];
		for (int k = 0; k < params.length; k++) {
			rmiParams[k] = params[k].getRMIImpl();
		}

		return rmiParams;
	}

	@Override
	public String[] listPublicInterfaceName() {
		return this.param.listPublicInterfaceName();
	}

	@Override
	public void addPublicInterface(String name) {
		this.param.addPublicInterface(name);
	}

	@Override
	public void setPublicInterface(String name, String param) {
		this.param.setPublicInterface(name, param);
	}

	@Override
	public void renamePublicInterface(String oldName, String newName) {
		this.param.renamePublicInterface(oldName, newName);
	}

	@Override
	public String removePublicInterface(String name) {
		return this.param.removePublicInterface(name);
	}

	@Override
	public String getPublicInterfaceParam(String name) {
		return this.param.getPublicInterfaceParam(name);
	}

	@Override
	public ParameterPath getPublicInterfacePath(String iname) {
		return this.param.getPublicInterfacePath(iname);
	}

	@Override
	public IComponent getComponent() throws RemoteException {
		Component comp;
		IComponent rmiComp = null;

		comp = this.param.getComponent();
		if (comp != null) {
			rmiComp = comp.getRMIImpl();
		}

		return rmiComp;
	}

	@Override
	public void addComponent() {
		this.param.addComponent();
	}

	@Override
	public void removeComponent() {
		this.param.removeComponent();
	}

	@Override
	public ParamContainer convertToParamContainer() {
		return this.param.convertToParamContainer();
	}

	@Override
	public ParamMaterial convertToParamMaterial() {
		return this.param.convertToParamMaterial();
	}

	@Override
	public ParamCollector convertToParamCollector() {
		return this.param.convertToParamCollector();
	}

	@Override
	public ParamFunction convertToParamMatlabFunction(String classPath, String className) {
		return this.param.convertToParamMatlabFunction(classPath, className);
	}

	@Override
	public ParamFunction convertToParamPythonFunction(String classPath, String className) {
		return this.param.convertToParamPythonFunction(classPath, className);
	}

	@Override
	public ParamFunction convertToParamJavaFunction(String classPath, String className) {
		return this.param.convertToParamJavaFunction(classPath, className);
	}

	@Override
	public CParamContainer getClientImpl() {
		return new CParamContainer(this);
	}
}
