/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui;

import java.io.File;

import javax.swing.JFileChooser;

import magopt.gui.helpers.JProgressDialog;
import magopt.gui.helpers.JProjectChooser;
import magopt.utils.MopFile;
import at.lcm.bu21.magopt.structure.Project;

/**
 * Runs Open Process in a non-EDT Thread.
 * 
 * @author Aigner Markus
 * 
 */
public class OpenThread extends BaseThread {
	private File mFile;

	protected OpenThread(MagOptGui gui) {
		super(gui);
		JProjectChooser chooser = new JProjectChooser(JProjectChooser.ALL,
				new File("."));
		int returnVal = chooser.showOpenDialog(gui);
		if (returnVal == JFileChooser.APPROVE_OPTION) {
			this.mFile = chooser.getSelectedFile();
			this.mPD = new JProgressDialog(gui, "Open Project", "Opening ...");
		} else {
			this.cancel(true);
		}
	}

	@Override
	protected Void doInBackground() throws Exception {
		this.mGui.mProject = Project.load(new MopFile(this.mFile));
		return null;
	}

	@Override
	protected void done() {
		if (this.isCancelled() == true) {
			return;
		}

		this.mGui.mProjectTree.setProject(this.mGui.mProject);
		this.mGui.mDataSetView.setProject(this.mGui.mProject);
		this.mGui.mParamView.set(this.mGui.mProject);
		this.mGui.mEventView.setEventLog(this.mGui.mProject.getEventLog());

		this.mGui.updateBars();
		this.mGui.setTitle(MagOptGui.GUITITLE + " - " + Project.getVersion()
				+ " - " + this.mGui.mProject.getMopFile().getAbsolutePath());
		this.mPD.setVisible(false);
	}
}
