/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.helpers;

import javax.swing.BorderFactory;
import javax.swing.BoxLayout;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JProgressBar;

/**
 * Displays non-modal Dialog with Progress Bar and disables/enables Parent
 * dependent of Visibility.
 * 
 * @author Aigner Markus
 * 
 */
public class JProgressDialog extends JDialog {
	private static final long serialVersionUID = 1L;

	private JProgressBar mJProgBar;

	public JProgressDialog(JFrame parent, String title, String text, int min,
			int max) {
		this(parent, title, text);
		this.mJProgBar.setIndeterminate(false);
		this.mJProgBar.setMinimum(min);
		this.mJProgBar.setMaximum(max);
	}

	public JProgressDialog(JFrame parent, String title, String text) {
		super(parent, false);
		JPanel pane = new JPanel();
		BoxLayout layout = new BoxLayout(pane, BoxLayout.Y_AXIS);
		pane.setLayout(layout);
		pane.setBorder(BorderFactory.createEmptyBorder(5, 10, 5, 10));
		this.setTitle(title);
		this.setDefaultCloseOperation(JFrame.DISPOSE_ON_CLOSE);
		this.setLocationRelativeTo(parent);
		this.setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);

		this.mJProgBar = new JProgressBar();
		this.mJProgBar.setIndeterminate(true);
		this.mJProgBar.setString(text);
		this.mJProgBar.setStringPainted(true);
		pane.add(this.mJProgBar);
		this.setContentPane(pane);
		this.pack();
		this.setVisible(true);
	}

	/**
	 * Sets new Progress Bar Value.
	 * 
	 * @param progress
	 *            - Progress Bar Value
	 */
	public void setValue(int progress) {
		this.mJProgBar.setValue(progress);
	}

	/**
	 * Disables Parent when visibility is set to true.<br>
	 * Enables Parent when visibility is set to false.<br>
	 * Also requests Focus for Parent after visibility is set to false.
	 */
	@Override
	public void setVisible(boolean visible) {
		super.setVisible(visible);

		/* return if no parent is null */
		if (this.getParent() == null) {
			return;
		}

		if (visible == true) {
			this.getParent().setEnabled(false);
		} else {
			this.getParent().setEnabled(true);
			this.getParent().requestFocus();
		}
	}
}
