/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.tree;

import javax.swing.JComponent;
import javax.swing.JTree;
import javax.swing.TransferHandler;
import javax.swing.tree.TreePath;

/**
 * This class is used to handle the transfer of a Transferable to and from
 * project tree
 * 
 * @author Werner Koppelsttter
 */
public class ProjectTreeTransferHandler extends TransferHandler {

	/** Serialization version number */
	private static final long serialVersionUID = 1L;

	/**
	 * Indicates whether the component will accept an import. This method is
	 * called repeatedly during drag and drop operation.
	 * 
	 * @param info
	 * @return true if the data can be inserted into the component, false
	 *         otherwise
	 */
	@Override
	public boolean canImport(TransferHandler.TransferSupport info) {

		// System.out.println("TransferHandler: can drop");
		if (!info.isDrop()) {
			return false;
		}
		// // we only import Strings
		// if (!info.isDataFlavorSupported(DataFlavor.stringFlavor)) {
		// return false;
		// }

		// fetch the drop location
		JTree.DropLocation dl = (JTree.DropLocation) info.getDropLocation();
		TreePath path = dl.getPath();

		// JTree.DropLocation dropLocation = (JTree.DropLocation)
		// info.getDropLocation();
		// int dix = dropLocation.getChildIndex();
		// System.out.println("dix: " + dix);

		// enable import only for void paths
		if (path == null) {
			return false;
		}
		return true;
	}

	/**
	 * Causes a transfer to occur from a clipboard or a drag and drop operation
	 * 
	 * @param info
	 *            the object containing the details of the transfer, not null.
	 * @return true if the data was inserted into the component, false otherwise
	 */
	@Override
	public boolean importData(TransferHandler.TransferSupport info) {
		// // if we can't handle the import, say so
		// System.out.println("TransferHandler: import data");

		if (!canImport(info)) {
			return false;
		}
		return true;
		//
		// // fetch the drop location
		// JTree.DropLocation dl = (JTree.DropLocation) info.getDropLocation();
		//
		// // fetch the path and child index from the drop location
		// TreePath path = dl.getPath();
		// int childIndex = dl.getChildIndex();
		//
		// // fetch the data and bail if this fails
		// String data;
		// try {
		// if (info.isDataFlavorSupported(DataFlavor.stringFlavor)) {
		// data = (String) info.getTransferable().getTransferData(
		// DataFlavor.stringFlavor);
		// } else if (info
		// .isDataFlavorSupported(DataFlavor.javaFileListFlavor)) {
		// List<File> files = (List<File>) info.getTransferable()
		// .getTransferData(DataFlavor.stringFlavor);
		// data = files.get(0).getName();
		// } else {
		// return false;
		// }
		// } catch (UnsupportedFlavorException e) {
		// return false;
		// } catch (IOException e) {
		// return false;
		// }
		//
		// // if child index is -1, the drop was on top of the path, so
		// // we'll
		// // treat it as inserting at the end of that path's list of
		// // children
		// if (childIndex == -1) {
		// childIndex = tree.getModel().getChildCount(
		// path.getLastPathComponent());
		// }
		//
		// // create a new node to represent the data and insert it into
		// // the model
		// DefaultMutableTreeNode newNode = new DefaultMutableTreeNode(data);
		// DefaultMutableTreeNode parentNode = (DefaultMutableTreeNode) path
		// .getLastPathComponent();
		// ((DefaultTreeModel) tree.getModel()).insertNodeInto(newNode,
		// parentNode, childIndex);
		//
		// // make the new node visible and scroll so that it's visible
		// tree.makeVisible(path.pathByAddingChild(newNode));
		// tree.scrollRectToVisible(tree.getPathBounds(path
		// .pathByAddingChild(newNode)));
		//
		// return true;
	}

	public void exportAsDrag(JComponent comp, java.awt.event.InputEvent e, int action) {

		// int zz = 0;
		// zz *= 2;
		// System.out.println("TransferHandler");
	}

	// @Override
	// public int getSourceActions(JComponent c) {
	// return COPY_OR_MOVE;
	// }

	// protected Transferable createTransferable(JComponent c) {
	// JTree tree = (JTree) c;
	// Object[] values = tree.getSelectionPath().getPath();
	//
	// StringBuffer buff = new StringBuffer();
	//
	// for (int i = 0; i < values.length; i++) {
	// Object val = values[i];
	// buff.append(val == null ? "" : val.toString());
	// if (i != values.length - 1) {
	// buff.append("\n");
	// }
	// }
	// return new StringSelection(buff.toString());
	// }

	// @Override
	// protected void exportDone(JComponent c, Transferable data, int action) {
	// if (action == MOVE) {
	// JTree tree = (JTree) c;
	// DefaultTreeModel model = (DefaultTreeModel) tree.getModel();
	// // Remove nodes saved in nodesToRemove in
	// // createTransferable.
	// // for(int i = 0; i < nodesToRemove.length; i++) {
	// // model.removeNodeFromParent(nodesToRemove[i]);
	// // }
	// }
	// }

}
