/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 9714 $
 * $Date: 2020-03-19 09:37:13 +0100 (Thu, 19 Mar 2020) $
 */
package magopt.gui.view.details;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusEvent;
import java.awt.event.FocusListener;
import java.rmi.RemoteException;

import javax.swing.ButtonGroup;
import javax.swing.GroupLayout;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JTextField;

import magopt.gui.helpers.DataEditor;
import magopt.gui.view.ParamBaseNoScroll;
import magopt.gui.view.port.PortView;
import at.lcm.bu21.magopt.structure.DependDirection;
import at.lcm.bu21.magopt.structure.FormulaType;
import at.lcm.bu21.magopt.structure.IParamFormula;
import at.lcm.bu21.magopt.structure.ParamField;

/**
 * Displays ParamFormula specific Data:<br>
 * - Expression<br>
 * - Data<br>
 * - Unit<br>
 * - Tex String<br>
 * - Type - Imports
 * 
 * @author Aigner Markus
 * @author Werner Koppelsttter
 */
public class ParamFormulaView extends ParamBaseNoScroll implements
		ActionListener, FocusListener {
	private static final long serialVersionUID = 1L;

	private JTextField mName;
	private JTextField mDescription;
	private JTextField mComment;

	protected ButtonGroup mFormulaTypeGroup;
	protected JRadioButton mFormulaTypeJava;
	protected JRadioButton mFormulaTypeMatlab;
	protected JRadioButton mFormulaTypePython;

	private JTextField mExpression;
	protected JTextField mData;
	protected JTextField mUnit;
	protected JTextField mTexString;
	protected JTextField mType;

	protected JButton bEdit;
	protected JButton bShow;

	protected boolean show;

	protected PortView mImports;

	private IParamFormula mPFormula;

	public ParamFormulaView() {
		JPanel mainPane = new JPanel();
		this.setLayout(new BorderLayout());
		this.add(mainPane);

		GroupLayout layout = new GroupLayout(mainPane);
		mainPane.setLayout(layout);
		layout.setAutoCreateGaps(true);
		layout.setAutoCreateContainerGaps(true);

		/* name */
		JLabel lName = new JLabel("Name:");
		this.mName = new JTextField();
		this.mName.addActionListener(this);
		this.mName.addFocusListener(this);

		/* description */
		JLabel lDesc = new JLabel("Description:");
		this.mDescription = new JTextField();
		this.mDescription.addActionListener(this);
		this.mDescription.addFocusListener(this);

		/* comment */
		JLabel lComment = new JLabel("Comment:");
		this.mComment = new JTextField();
		this.mComment.addActionListener(this);
		this.mComment.addFocusListener(this);

		/* formula type */
		JLabel lFormulaType = new JLabel("Formula:");
		this.mFormulaTypeGroup = new ButtonGroup();
		this.mFormulaTypeJava = new JRadioButton("Java");
		this.mFormulaTypeJava.addActionListener(this);
		this.mFormulaTypeGroup.add(this.mFormulaTypeJava);
		this.mFormulaTypeMatlab = new JRadioButton("Matlab");
		this.mFormulaTypeMatlab.addActionListener(this);
		this.mFormulaTypeGroup.add(this.mFormulaTypeMatlab);
		this.mFormulaTypePython = new JRadioButton("Python");
		this.mFormulaTypePython.addActionListener(this);
		this.mFormulaTypeGroup.add(this.mFormulaTypePython);
		// FIXME
		this.mFormulaTypePython.setVisible(false);

		/* expression */
		JLabel lExpression = new JLabel("Expression:");
		this.mExpression = new JTextField();
		this.mExpression.addActionListener(this);
		this.mExpression.addFocusListener(this);

		/* data */
		JLabel lData = new JLabel("Data:");
		this.mData = new JTextField();
		this.mData.setEditable(false);

		/* edit */
		this.bEdit = new JButton("Edit");
		this.bEdit.addActionListener(this);
		// this.bEdit.addFocusListener(this);

		/* show */
		this.bShow = new JButton("Show");
		this.bShow.addActionListener(this);
		// this.bShow.addFocusListener(this);

		/* unit */
		JLabel lUnit = new JLabel("Unit:");
		this.mUnit = new JTextField();
		this.mUnit.addActionListener(this);
		this.mUnit.addFocusListener(this);

		/* tex string */
		JLabel lTexString = new JLabel("Tex String:");
		this.mTexString = new JTextField();
		this.mTexString.addActionListener(this);
		this.mTexString.addFocusListener(this);

		/* type */
		JLabel lType = new JLabel("Type:");
		this.mType = new JTextField();
		this.mType.addActionListener(this);
		this.mType.addFocusListener(this);

		/* imports */
		JLabel lImports = new JLabel("Imports");
		this.mImports = new PortView();
		// this.mImports.addActionListener(this);

		/* config group layout */
		layout.setHorizontalGroup(layout
				.createSequentialGroup()
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.LEADING)
								.addComponent(lName).addComponent(lDesc)
								.addComponent(lComment)
								.addComponent(lFormulaType)
								.addComponent(lExpression).addComponent(lData)
								.addComponent(lUnit).addComponent(lTexString)
								.addComponent(lType).addComponent(lImports))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.LEADING)
								.addComponent(this.mName)
								.addComponent(this.mDescription)
								.addComponent(this.mComment)
								.addGroup(
										layout.createSequentialGroup()
												.addComponent(
														this.mFormulaTypeJava)
												.addComponent(
														this.mFormulaTypeMatlab)
												.addComponent(
														this.mFormulaTypePython))
								.addComponent(this.mExpression)
								.addComponent(this.mData)
								.addGroup(
										layout.createSequentialGroup()
												.addComponent(this.bEdit)
												.addComponent(this.bShow))
								.addComponent(this.mUnit)
								.addComponent(this.mTexString)
								.addComponent(this.mType)
								.addComponent(this.mImports))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.LEADING).addComponent(
								this.bShow)));

		layout.setVerticalGroup(layout
				.createSequentialGroup()
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lName).addComponent(this.mName))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lDesc)
								.addComponent(this.mDescription))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lComment)
								.addComponent(this.mComment))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lFormulaType)
								.addComponent(this.mFormulaTypeJava)
								.addComponent(this.mFormulaTypeMatlab)
								.addComponent(this.mFormulaTypePython))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lExpression)
								.addComponent(this.mExpression))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lData).addComponent(this.mData))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(this.bEdit)
								.addComponent(this.bShow))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lUnit).addComponent(this.mUnit))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lTexString)
								.addComponent(this.mTexString))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lType).addComponent(this.mType))
				.addGroup(
						layout.createParallelGroup(
								GroupLayout.Alignment.BASELINE)
								.addComponent(lImports)
								.addComponent(this.mImports)));

	}

	@Override
	public void focusGained(FocusEvent e) {
		/* do nothing */
	}

	@Override
	public void focusLost(FocusEvent e) {
		this.doWork(e.getSource());
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		this.doWork(e.getSource());
	}

	private void doWork(Object obj) {
		try {
			if (obj == this.mName) {
				this.mPFormula.setName(this.mName.getText());
			} else if (obj == this.mDescription) {
				this.mPFormula.setDescription(this.mDescription.getText());
			} else if (obj == this.mComment) {
				this.mPFormula.setComment(this.mComment.getText());
			} else if (obj == this.mUnit) {
				this.mPFormula.setUnit(this.mUnit.getText());
			} else if (obj == this.mTexString) {
				this.mPFormula.setTexString(this.mTexString.getText());
			} else if (obj == this.mType) {
				this.mPFormula.setType(this.mType.getText());
			} else if (obj == this.mFormulaTypeJava) {
				if (this.mFormulaTypeJava.isSelected()) {
					this.mPFormula.setFormulaType(FormulaType.JAVA);
				}
			} else if (obj == this.mFormulaTypeMatlab) {
				if (this.mFormulaTypeMatlab.isSelected()) {
					this.mPFormula.setFormulaType(FormulaType.MATLAB);
				}
			} else if (obj == this.mFormulaTypePython) {
				if (this.mFormulaTypePython.isSelected()) {
					this.mPFormula.setFormulaType(FormulaType.PYTHON);
				}
			} else if (obj == this.mExpression) {
				this.mPFormula.setExpression(this.mExpression.getText());
			} else if (obj == this.bEdit) {
				// FIXME RMI
				new DataEditor((ParamField) this.mPFormula);
			} else if (obj == this.bShow) {
				this.show = true;
				this.bShow.setEnabled(!this.show);
			}
		} catch (RemoteException ex) {
			ex.printStackTrace();
		} catch (Exception ex) {
			try {
				this.mPFormula.error(ex.getMessage(), ex.getStackTrace());
			} catch (RemoteException e) {
				e.printStackTrace();
			}
		}

		this.update();
		this.fireParamChanged();
	}

	/**
	 * Sets new ParamFormula.
	 * 
	 * @param pFormula
	 *            - ParamFormula
	 */
	public void setFormula(IParamFormula pFormula) {
		this.mPFormula = pFormula;
		try {
			this.show = !this.mPFormula.getUncertain();
			this.bShow.setEnabled(!this.show);
		} catch (RemoteException e) {
			e.printStackTrace();
		}
		this.update();
	}

	@Override
	protected void update() {
		try {
			this.mName.setText(this.mPFormula.getName());
			this.mDescription.setText(this.mPFormula.getDescription());
			this.mComment.setText(this.mPFormula.getComment());
			if (this.show) {
				this.mData.setText(this.mPFormula.getData().toString());
			} else {
				this.mData.setText("[Uncertain]");
			}
			this.mUnit.setText(this.mPFormula.getUnit());
			this.mTexString.setText(this.mPFormula.getTexString());
			this.mType.setText(this.mPFormula.getType());
			switch (this.mPFormula.getFormulaType()) {
			case JAVA:
				this.mFormulaTypeJava.setSelected(true);
				break;
			case MATLAB:
				this.mFormulaTypeMatlab.setSelected(true);
				break;
			case PYTHON:
				this.mFormulaTypePython.setSelected(true);
				break;
			}
			this.mExpression.setText(this.mPFormula.getExpression());
			this.mImports.setDepend(this.mPFormula.getDepend(),
					DependDirection.IMPORT);
		} catch (RemoteException e) {
			e.printStackTrace();
		}
	}

}
