/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 247 $
 * $Date: 2020-03-19 10:13:52 +0100 (Thu, 19 Mar 2020) $
 */
package at.lcm.bu21.optim.core.event;

/**
 * Optimizer event
 * 
 * @author Werner Koppelsttter
 */
public class OptimizerEvent {

	/** Status changed */
	public final static int STATUS = 0x01;

	/** Log changed */
	public final static int LOG = 0x02;

	/** Problem changed */
	public final static int PROBLEM = 0x04;

	/** Count of plots changed */
	public final static int PLOT = 0x08;

	/** Mappings changed */
	public final static int MAPPING = 0x10;

	/** Individual selected for sensitivity analysis changed */
	public final static int SENSITIVITY = 0x20;

	/** Individual selected for sensitivity analysis changed */
	public final static int POOL = 0x40;

	/** Type of event */
	private int type;

	/** Message of event */
	private String message;

	/**
	 * Create optimizer event
	 * 
	 * @param type
	 *            Type of event
	 */
	public OptimizerEvent(int type) {
		this.type = type;
	}

	/**
	 * Create optimizer event
	 * 
	 * @param type
	 *            Type of event
	 * @param message
	 *            Message
	 */
	public OptimizerEvent(int type, String message) {
		this.type = type;
		this.message = message;
	}

	/**
	 * Get type of optimizer event
	 * 
	 * @return Type
	 */
	public int getType() {
		return this.type;
	}

	/**
	 * Get message of optimizer event
	 * 
	 * @return Message
	 */
	public String getMessage() {
		return this.message;
	}
}
