#!/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 10062 $
$LastChangedDate:: 2020-11-20 13:22:02 +0100#$

This file is part of SyMSpace.

Copyright (c) 2018, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""

import os
from lcm.tdata_interface.pyjdata_interface import PyJDataInterface
from lcm.utils.serialization import Serializable
from symspace.generic_gui_qt import GUIFormThread
from symspace.console.script_utils import ScriptUtils
from symspace.wrapper.symwrapper import SymProject, SymFunction, SymContainer, SymParameter


def main(project: SymProject, parameter: SymParameter):

    if isinstance(parameter, (SymContainer, SymFunction)):
        raise Exception('Containers and Functions are not supported for export!')
    else:
        data = PyJDataInterface.convert_J2Py(parameter.javaObj.getData())

        default_path = os.path.join(project.getDirectory(), parameter.getName() + '.mat')
        form_title = 'Select destination for ComponentSpace'
        form_elements = [('Select destination', 'save_file', default_path,
                          'Pickle Files (*.p *.pickle);;MAT-files (*.mat);;CBOR-files (*.cbor)')
                         ]
        form = GUIFormThread(form_title, form_elements)

        form.start()

        if form.accept:
            path = os.path.join(form.result['Select destination'])

            Serializable.saveFile(data, path)
            project.info('File saved to: {}'.format(path))
            print('Export finished')
        else:
            print('Cancelled by user')


if __name__ == '__main__':
    """
    This script exports a parameter as Pickle(.p, .pickle), CBOR (*.cbor) or MAT-files (*.mat)
    
    This script needs to be executed in the SyMSpace Python Console.
    """
    _params = locals()
    _project = ScriptUtils.getProject(_params)
    _parameter = ScriptUtils.getParameter(_params)
    if _project is not None:
        ScriptUtils.run(main, _project, _parameter)
    else:
        ScriptUtils.showNoProjectWarning()

