# !/usr/bin/python
# -*- coding: <UTF-8> -*-

"""
Python Version : 3.6

$LastChangedRevision: 10062 $
$LastChangedDate:: 2020-11-20 13:22:02 +0100#$

This file is part of SyMSpace.

Copyright (c) 2020, Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
All rights reserved.
"""
import os
from symspace.generic_gui_qt import GUIFormThread
from symspace.console.script_utils import ScriptUtils
from symspace.wrapper.symoptwrapper import SymXLSWrite, SymArchive
import ast


def main(params: dict):
    project = ScriptUtils.selectProjectFromParams(params)
    if project is not None:
        xls_path_default = os.path.join(project.getDirectory(), 'Optimizer_Export')
        prj_file = project.getFile(get_abs_path=True)
        individual_types = ['all', 'valid', 'no_error', 'error', 'pareto']
        archive_problem_list = ScriptUtils.getProblemsList(prj_file)
        archive_problem_list.append('all')
        objectives = ScriptUtils.getObjectivesList(project)

        form_title = 'Plot Excel file exports'
        form_elements = [
            ('Select Excel directory', 'browse_folder', xls_path_default),
            ('Plot Type', 'combobox', ['XY-Plot', 'Histogram']),
            ('x-Labels', 'line', str(objectives)),
            ('y-Labels', 'line', str(objectives)),
            ('Use existing Excel files', 'checkbox', False),
            ('', 'label'),
            ('Use existing Excel files == False', 'label'),
            ('Archive//Problem Name', 'combobox', archive_problem_list),
            ('Individual Type', 'combobox', individual_types),
        ]
        form = GUIFormThread(form_title, form_elements)

        form.start()
        if form.accept:
            xls_dir = form.result['Select Excel directory']
            use_existing = form.result['Use existing Excel files']
            plot_type = form.result['Plot Type']
            x_labels = ast.literal_eval(form.result['x-Labels'])
            y_labels = ast.literal_eval(form.result['y-Labels'])

            if not use_existing:
                individual_type = form.result['Individual Type']
                archive_problem = form.result['Archive//Problem Name']

                if archive_problem == 'all':
                    SymXLSWrite.exportMultipleXLSReports(prj_file, xls_dir, archive_names=None, problem_names=None,
                                                         individual_type=individual_type)
                else:
                    archive_name, problem_name = ScriptUtils.parseArchiveProblemName(archive_problem)

                    archive = SymArchive.load(prj_file, archive_name)
                    problem = archive.readProblem(problem_name)
                    file = os.path.join(xls_dir,
                                        SymXLSWrite.getStandardFileName(archive_name, problem_name, individual_type))

                    SymXLSWrite.writeXLSReportMemory(problem, file, individual_type)

            if plot_type == 'XY-Plot':
                plot = SymXLSWrite.plotComparison(xls_dir, x_labels, y_labels, rename_objective=True)
            else:
                plot = SymXLSWrite.plotHistogramm(xls_dir, x_labels, rename_objective=True)

            plot.show()

            print('Update finished')
        else:
            print('Cancelled by user')


if __name__ == '__main__':
    """
    This script plots Optimization exports from Excel spread sheet(s)

    This script needs to be executed in the SyMSpace Python Console.
    """
    _params = locals()
    ScriptUtils.run(main, _params)

