/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 10085 $
 * $Date: 2020-12-29 09:13:44 +0100 (Di., 29 Dez 2020) $
 */
package at.lcm.symspace.optimizer.rest.plot;

import at.lcm.bu21.optim.core.Problem;
import at.lcm.bu21.optim.core.plot.PlotJson;
import at.lcm.bu21.optim.core.plot.PlotJson.ResultType;
import jakarta.ws.rs.GET;
import jakarta.ws.rs.OPTIONS;
import jakarta.ws.rs.Path;
import jakarta.ws.rs.PathParam;
import jakarta.ws.rs.Produces;
import jakarta.ws.rs.core.MediaType;
import jakarta.ws.rs.core.Response;

@Path("/plot")
public class Plot { // implements IProject {

	static boolean plotVariables = false;
	static PlotJson.ResultType plotResults = ResultType.OBJECTIVES;
	static Problem problem = null;

	public static void setProblem(Problem problem, boolean plotVariables, PlotJson.ResultType plotResults) {
		Plot.plotVariables = plotVariables;
		Plot.plotResults = plotResults;
		Plot.problem = problem;
	}

	public static String getName() {
		String name = null;

		if (problem != null) {
			name = problem.getArchive().getMop().getName();
			name = name.substring(0, name.length() - 4);
			name += "_" + problem.getArchive().getName() + "_" + problem.getName();
			name += "_SP" + problem.getNumSavePoints();
			if (plotVariables)
				name += "_Variables";
			switch (plotResults) {
			case OBJECTIVES:
				name += "_Objectives";
				break;
			case CONSTAINTS:
				name += "_Objectives_Contraints";
				break;
			case RESULTS:
				name += "_Results";
				break;
			}
		}

		return name;
	}

	@GET
	@Path("{name}")
	@Produces(MediaType.APPLICATION_JSON)
	public String getProjectURL(@PathParam("name") String name) {
		String str = "";

		if (problem != null) {
			if (getName().equals(name)) {
				System.out.println("Request: " + name);
				str = PlotJson.getJsonString(problem, plotVariables, plotResults);
			} else {
				System.out.println("Request: Wrrong name");
			}
		} else {
			System.out.println("Request: File doesn't exist");
		}

		return str;
	}

	@OPTIONS
	@Produces(MediaType.APPLICATION_JSON)
	public Response optionsFoListResource() {
		return Response.status(200).header("Allow", "POST, PUT, GET").header("Content-Type", MediaType.APPLICATION_JSON)
				.header("Content-Length", "0").build();
	}
}
