/*
 * This file is part of SyMSpace.
 * 
 * Copyright(c)2020,Linz Center of Mechatronics GmbH (LCM) http://www.lcm.at/
 * All rights reserved.
 * 
 * This program is free software; you can redistribute it and/or modify it under 
 * the terms of the GNU General Public License, version 2.0 (GPLv2), as published 
 * by the Free Software Foundation.
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY 
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A 
 * PARTICULAR PURPOSE. See the GNU General Public License, version 2.0, for more 
 * details.
 * The GPLv2 can be found in the licenses folder as gpl-2.0.txt.
 * 
 * $Revision: 10085 $
 * $Date: 2020-12-29 09:13:44 +0100 (Di., 29 Dez 2020) $
 */
package at.lcm.symspace.optimizer.rest.plot;

import java.awt.Desktop;
import java.io.IOException;
import java.net.ServerSocket;
import java.net.URI;

import org.glassfish.grizzly.http.server.HttpServer;
import org.glassfish.jersey.grizzly2.httpserver.GrizzlyHttpServerFactory;
import org.glassfish.jersey.server.ResourceConfig;

import at.lcm.bu21.magopt.utils.MagOptConfig;
import at.lcm.bu21.optim.core.Problem;
import at.lcm.bu21.optim.core.plot.PlotJson;

/**
 * Main class.
 *
 */
public class RESTWebPlotServer {

	private static int defaultPort = 0;
	private static int port = 0;

	private static HttpServer server = null;

	// Base URI the Grizzly HTTP server will listen on
	public static String getBaseUri() {
		return "http://localhost:" + port + "/symspace/optimizer";
	}

	public static void setDefaultPort(int port) {
		defaultPort = port;
	}

	public static int getPort() {
		return port;
	}

	public static String getOptimization() {
		return Plot.getName();
	}

	public static void browse() {
		if (getOptimization() != null && isAvailable()) {
			if (!isRunning()) {
				startServer();
			}

			try {
				URI uri = new URI(
						String.format("%s/%s/%d", MagOptConfig.getConfig("WebplotURL"), getOptimization(), getPort()));
				System.out.println("browse: " + uri);
				if (Desktop.isDesktopSupported()) {
					Desktop.getDesktop().browse(uri);
				}
			} catch (Exception e) {
				System.err.println(e.getMessage());
				e.printStackTrace();
			}
		}
	}

	/**
	 * Starts Grizzly HTTP server exposing JAX-RS resources defined in this
	 * application.
	 * 
	 * @return Grizzly HTTP server.
	 */
	public static void startServer() {
//		String tmp;

		stopServer();

		try {
			ServerSocket ss = new ServerSocket(defaultPort);
			port = ss.getLocalPort();
			ss.close();

			// create a resource config that scans for JAX-RS resources and providers
			// in at.lcm.symspace.rest package
			final ResourceConfig rc = new ResourceConfig();
			URI uri = new URI(MagOptConfig.getConfig("WebplotURL"));
			rc.register(new CorsFilter(String.format("%s://%s", uri.getScheme(), uri.getHost())));
			rc.register(Plot.class);
//		rc.packages("at.lcm.symspace.optimiizer.rest");

//		SSLContextConfigurator sslContextConfiguration = new SSLContextConfigurator();
//		sslContext.setKeyStoreFile(keyStoreFile);

			// create and start a new instance of grizzly http server
			// exposing the Jersey application at BASE_URI
//		return GrizzlyHttpServerFactory.createHttpServer(URI.create(BASE_URI), rc, true,
//				new SSLEngineConfigurator(sslContextConfiguration, false, false, false));
			server = GrizzlyHttpServerFactory.createHttpServer(URI.create(getBaseUri()), rc);

			System.out.println(String.format("Server started at %s", getBaseUri() + "/plot"));

		} catch (Exception e) {
			System.err.println(e.getMessage());
			e.printStackTrace();
		}

	}

	/**
	 * Stops Grizzly HTTP server exposing JAX-RS resources defined in this
	 * application.
	 * 
	 * @return Grizzly HTTP server.
	 */
	public static void stopServer() {
		if (server != null) {
			server.shutdownNow();
			server = null;
			port = 0;
		}
	}

	public static boolean isRunning() {
		return server != null;
	}

	public static void setProblem(Problem problem, boolean plotVariables, PlotJson.ResultType plotResults) {
		Plot.setProblem(problem, plotVariables, plotResults);
	}

	public static boolean isAvailable() {
		boolean available = true;
		if (!isRunning()) {

			if (defaultPort != 0) {
				try {
					new ServerSocket(port).close();
				} catch (IOException e) {
//			System.err.println(e.getMessage());
//			e.printStackTrace();
					available = false;
				}
			}
		}
		return available;
	}
}
